All of lore.kernel.org
 help / color / mirror / Atom feed
* [rtc-linux] [PATCH] drivers/rtc/rtc-efi.c: Update author email address
@ 2015-04-24 17:54 dann frazier
  2015-05-03  9:51 ` Alexandre Belloni
  0 siblings, 1 reply; 2+ messages in thread
From: dann frazier @ 2015-04-24 17:54 UTC (permalink / raw)
  To: rtc-linux

I'm no longer employed by HP.

Signed-off-by: dann frazier <dannf@dannf.org>
---
 drivers/rtc/rtc-efi.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/drivers/rtc/rtc-efi.c b/drivers/rtc/rtc-efi.c
index cb989cd..c5fbabb 100644
--- a/drivers/rtc/rtc-efi.c
+++ b/drivers/rtc/rtc-efi.c
@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2009 Hewlett-Packard Development Company, L.P.
  *
  * Author: dann frazier <dannf@hp.com>
  * Based on efirtc.c by Stephane Eranian
  *
  *  This program is free software; you can redistribute  it and/or modify it
@@ -233,7 +233,7 @@ static struct platform_driver efi_rtc_driver = {
 module_platform_driver_probe(efi_rtc_driver, efi_rtc_probe);
 
 MODULE_ALIAS("platform:rtc-efi");
-MODULE_AUTHOR("dann frazier <dannf@hp.com>");
+MODULE_AUTHOR("dann frazier <dannf@dannf.org>");
 MODULE_LICENSE("GPL");
 MODULE_DESCRIPTION("EFI RTC driver");
 MODULE_ALIAS("platform:rtc-efi");
@@ -3,7 +3,7 @@
  * Copyright (C) 2009 Hewlett-Packard Development Company, L.P.
  *
- * Author: dann frazier <dannf@hp.com>
+ * Author: dann frazier <dannf@dannf.org>
  * Based on efirtc.c by Stephane Eranian
  *
-- 
2.1.4

-- 
-- 
You received this message because you are subscribed to "rtc-linux".
Membership options at http://groups.google.com/group/rtc-linux .
Please read http://groups.google.com/group/rtc-linux/web/checklist
before submitting a driver.
--- 
You received this message because you are subscribed to the Google Groups "rtc-linux" group.
To unsubscribe from this group and stop receiving emails from it, send an email to rtc-linux+unsubscribe@googlegroups.com.
For more options, visit https://groups.google.com/d/optout.

^ permalink raw reply related	[flat|nested] 2+ messages in thread

* Re: [rtc-linux] [PATCH] drivers/rtc/rtc-efi.c: Update author email address
  2015-04-24 17:54 [rtc-linux] [PATCH] drivers/rtc/rtc-efi.c: Update author email address dann frazier
@ 2015-05-03  9:51 ` Alexandre Belloni
  0 siblings, 0 replies; 2+ messages in thread
From: Alexandre Belloni @ 2015-05-03  9:51 UTC (permalink / raw)
  To: dann frazier; +Cc: rtc-linux

On 24/04/2015 at 11:54:20 -0600, dann frazier wrote :
> I'm no longer employed by HP.
> 
> Signed-off-by: dann frazier <dannf@dannf.org>
> ---
>  drivers/rtc/rtc-efi.c | 4 ++--
>  1 file changed, 2 insertions(+), 2 deletions(-)
> 

Applied, thanks.

-- 
Alexandre Belloni, Free Electrons
Embedded Linux, Kernel and Android engineering
http://free-electrons.com

-- 
-- 
You received this message because you are subscribed to "rtc-linux".
Membership options at http://groups.google.com/group/rtc-linux .
Please read http://groups.google.com/group/rtc-linux/web/checklist
before submitting a driver.
--- 
You received this message because you are subscribed to the Google Groups "rtc-linux" group.
To unsubscribe from this group and stop receiving emails from it, send an email to rtc-linux+unsubscribe@googlegroups.com.
For more options, visit https://groups.google.com/d/optout.

^ permalink raw reply	[flat|nested] 2+ messages in thread

end of thread, other threads:[~2015-05-03  9:51 UTC | newest]

Thread overview: 2+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2015-04-24 17:54 [rtc-linux] [PATCH] drivers/rtc/rtc-efi.c: Update author email address dann frazier
2015-05-03  9:51 ` Alexandre Belloni

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.